from .emojis import emojis
from .symbols import symbols
from .arrows import arrows
from .math_symbols import math_symbols
from .currency import currency
from .misc import misc

__all__ = ["emojis", "symbols", "arrows", "math_symbols", "currency", "misc"]

__version__ = "1.0.1"

__license__ = "MIT"

__author__ = "Vishwanath M M"




# math_symbols.py
math_symbols = {
    "plus": "+",
    "minus": "-",
    "multiply": "×",
    "divide": "÷",
    "equals": "=",
    "plus_minus": "±",
    "not_equals": "≠",
    "approximately": "≈",
    "less_than": "<",
    "greater_than": ">",
    "less_equal": "≤",
    "greater_equal": "≥",
    "infinity": "∞",
    "square_root": "√",
    "summation": "∑",
    "pi": "π",
    "theta": "θ",
    "alpha": "α",
    "beta": "β",
    "gamma": "γ",
    "delta": "δ",
    "epsilon": "ε",
    "zeta": "ζ",
    "eta": "η",
    "theta": "θ",
    "iota": "Ι",
    "kappa": "κ",
    "lambda": "λ",
    "mu": "μ",
    "nu": "ν",
    "xi": "ξ",
    "omicron": "ο",
    "pi": "π",
    "rho": "ρ",
    "sigma": "σ",
    "tau": "τ",
    "upsilon": "υ",
    "phi": "φ",
    "chi": "χ",
    "psi": "ψ",
    "omega": "ω",
    "prime": "'",
    "double_prime": "″",
    "triple_prime": "‴",
    "angle": "∠",
    "degree": "°",
    "perpendicular": "⊥",
    "parallel": "∥",
    "integral": "∫",
    "partial_derivative": "∂",
    "nabla": "∇",
    "therefore": "∴",
    "because": "∵",
    "element_of": "∈",
    "not_element_of": "∉",
    "subset": "⊂",
    "superset": "⊃",
    "proper_subset": "⊆",
    "proper_superset": "⊇",
    "union": "∪",
    "intersection": "∩"
}
